# Reader RBV

[![reader-rbv - PyPi](https://img.shields.io/pypi/v/reader-rbv)](https://pypi.org/project/reader-rbv/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/reader-rbv)](https://pypi.org/project/reader-rbv/)
[![LICENSE](https://img.shields.io/github/license/UnivTerbuka/reader-rbv)](https://github.com/UnivTerbuka/reader-rbv/blob/main/LICENSE)
[![Code Style - Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

SDK / Client python untuk Ruang Baca Virtual.
